@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Dict, List
+from typing import Any, Dict, List
 
 from .literals import (
     AttributeTypeType,
@@ -37,25 +37,47 @@ else:
 __all__ = (
     "CategoricalParameterRangeTypeDef",
     "ContinuousParameterRangeTypeDef",
-    "CreateDatasetGroupResponseTypeDef",
-    "CreateDatasetImportJobResponseTypeDef",
-    "CreateDatasetResponseTypeDef",
-    "CreateForecastExportJobResponseTypeDef",
-    "CreateForecastResponseTypeDef",
-    "CreatePredictorBacktestExportJobResponseTypeDef",
-    "CreatePredictorResponseTypeDef",
+    "CreateDatasetGroupRequestTypeDef",
+    "CreateDatasetGroupResponseResponseTypeDef",
+    "CreateDatasetImportJobRequestTypeDef",
+    "CreateDatasetImportJobResponseResponseTypeDef",
+    "CreateDatasetRequestTypeDef",
+    "CreateDatasetResponseResponseTypeDef",
+    "CreateForecastExportJobRequestTypeDef",
+    "CreateForecastExportJobResponseResponseTypeDef",
+    "CreateForecastRequestTypeDef",
+    "CreateForecastResponseResponseTypeDef",
+    "CreatePredictorBacktestExportJobRequestTypeDef",
+    "CreatePredictorBacktestExportJobResponseResponseTypeDef",
+    "CreatePredictorRequestTypeDef",
+    "CreatePredictorResponseResponseTypeDef",
     "DataDestinationTypeDef",
     "DataSourceTypeDef",
     "DatasetGroupSummaryTypeDef",
     "DatasetImportJobSummaryTypeDef",
     "DatasetSummaryTypeDef",
-    "DescribeDatasetGroupResponseTypeDef",
-    "DescribeDatasetImportJobResponseTypeDef",
-    "DescribeDatasetResponseTypeDef",
-    "DescribeForecastExportJobResponseTypeDef",
-    "DescribeForecastResponseTypeDef",
-    "DescribePredictorBacktestExportJobResponseTypeDef",
-    "DescribePredictorResponseTypeDef",
+    "DeleteDatasetGroupRequestTypeDef",
+    "DeleteDatasetImportJobRequestTypeDef",
+    "DeleteDatasetRequestTypeDef",
+    "DeleteForecastExportJobRequestTypeDef",
+    "DeleteForecastRequestTypeDef",
+    "DeletePredictorBacktestExportJobRequestTypeDef",
+    "DeletePredictorRequestTypeDef",
+    "DeleteResourceTreeRequestTypeDef",
+    "DescribeDatasetGroupRequestTypeDef",
+    "DescribeDatasetGroupResponseResponseTypeDef",
+    "DescribeDatasetImportJobRequestTypeDef",
+    "DescribeDatasetImportJobResponseResponseTypeDef",
+    "DescribeDatasetRequestTypeDef",
+    "DescribeDatasetResponseResponseTypeDef",
+    "DescribeForecastExportJobRequestTypeDef",
+    "DescribeForecastExportJobResponseResponseTypeDef",
+    "DescribeForecastRequestTypeDef",
+    "DescribeForecastResponseResponseTypeDef",
+    "DescribePredictorBacktestExportJobRequestTypeDef",
+    "DescribePredictorBacktestExportJobResponseResponseTypeDef",
+    "DescribePredictorRequestTypeDef",
+    "DescribePredictorResponseResponseTypeDef",
     "EncryptionConfigTypeDef",
     "ErrorMetricTypeDef",
     "EvaluationParametersTypeDef",
@@ -66,18 +88,27 @@ __all__ = (
     "FilterTypeDef",
     "ForecastExportJobSummaryTypeDef",
     "ForecastSummaryTypeDef",
-    "GetAccuracyMetricsResponseTypeDef",
+    "GetAccuracyMetricsRequestTypeDef",
+    "GetAccuracyMetricsResponseResponseTypeDef",
     "HyperParameterTuningJobConfigTypeDef",
     "InputDataConfigTypeDef",
     "IntegerParameterRangeTypeDef",
-    "ListDatasetGroupsResponseTypeDef",
-    "ListDatasetImportJobsResponseTypeDef",
-    "ListDatasetsResponseTypeDef",
-    "ListForecastExportJobsResponseTypeDef",
-    "ListForecastsResponseTypeDef",
-    "ListPredictorBacktestExportJobsResponseTypeDef",
-    "ListPredictorsResponseTypeDef",
-    "ListTagsForResourceResponseTypeDef",
+    "ListDatasetGroupsRequestTypeDef",
+    "ListDatasetGroupsResponseResponseTypeDef",
+    "ListDatasetImportJobsRequestTypeDef",
+    "ListDatasetImportJobsResponseResponseTypeDef",
+    "ListDatasetsRequestTypeDef",
+    "ListDatasetsResponseResponseTypeDef",
+    "ListForecastExportJobsRequestTypeDef",
+    "ListForecastExportJobsResponseResponseTypeDef",
+    "ListForecastsRequestTypeDef",
+    "ListForecastsResponseResponseTypeDef",
+    "ListPredictorBacktestExportJobsRequestTypeDef",
+    "ListPredictorBacktestExportJobsResponseResponseTypeDef",
+    "ListPredictorsRequestTypeDef",
+    "ListPredictorsResponseResponseTypeDef",
+    "ListTagsForResourceRequestTypeDef",
+    "ListTagsForResourceResponseResponseTypeDef",
     "MetricsTypeDef",
     "PaginatorConfigTypeDef",
     "ParameterRangesTypeDef",
@@ -85,13 +116,18 @@ __all__ = (
     "PredictorExecutionDetailsTypeDef",
     "PredictorExecutionTypeDef",
     "PredictorSummaryTypeDef",
+    "ResponseMetadataTypeDef",
     "S3ConfigTypeDef",
     "SchemaAttributeTypeDef",
     "SchemaTypeDef",
     "StatisticsTypeDef",
+    "StopResourceRequestTypeDef",
     "SupplementaryFeatureTypeDef",
+    "TagResourceRequestTypeDef",
     "TagTypeDef",
     "TestWindowSummaryTypeDef",
+    "UntagResourceRequestTypeDef",
+    "UpdateDatasetGroupRequestTypeDef",
     "WeightedQuantileLossTypeDef",
     "WindowSummaryTypeDef",
 )
@@ -127,62 +163,241 @@ class ContinuousParameterRangeTypeDef(
     pass
 
 
-CreateDatasetGroupResponseTypeDef = TypedDict(
-    "CreateDatasetGroupResponseTypeDef",
+_RequiredCreateDatasetGroupRequestTypeDef = TypedDict(
+    "_RequiredCreateDatasetGroupRequestTypeDef",
+    {
+        "DatasetGroupName": str,
+        "Domain": DomainType,
+    },
+)
+_OptionalCreateDatasetGroupRequestTypeDef = TypedDict(
+    "_OptionalCreateDatasetGroupRequestTypeDef",
+    {
+        "DatasetArns": List[str],
+        "Tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateDatasetGroupRequestTypeDef(
+    _RequiredCreateDatasetGroupRequestTypeDef, _OptionalCreateDatasetGroupRequestTypeDef
+):
+    pass
+
+
+CreateDatasetGroupResponseResponseTypeDef = TypedDict(
+    "CreateDatasetGroupResponseResponseTypeDef",
     {
         "DatasetGroupArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateDatasetImportJobRequestTypeDef = TypedDict(
+    "_RequiredCreateDatasetImportJobRequestTypeDef",
+    {
+        "DatasetImportJobName": str,
+        "DatasetArn": str,
+        "DataSource": "DataSourceTypeDef",
+    },
+)
+_OptionalCreateDatasetImportJobRequestTypeDef = TypedDict(
+    "_OptionalCreateDatasetImportJobRequestTypeDef",
+    {
+        "TimestampFormat": str,
+        "TimeZone": str,
+        "UseGeolocationForTimeZone": bool,
+        "GeolocationFormat": str,
+        "Tags": List["TagTypeDef"],
     },
     total=False,
 )
 
-CreateDatasetImportJobResponseTypeDef = TypedDict(
-    "CreateDatasetImportJobResponseTypeDef",
+
+class CreateDatasetImportJobRequestTypeDef(
+    _RequiredCreateDatasetImportJobRequestTypeDef, _OptionalCreateDatasetImportJobRequestTypeDef
+):
+    pass
+
+
+CreateDatasetImportJobResponseResponseTypeDef = TypedDict(
+    "CreateDatasetImportJobResponseResponseTypeDef",
     {
         "DatasetImportJobArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateDatasetRequestTypeDef = TypedDict(
+    "_RequiredCreateDatasetRequestTypeDef",
+    {
+        "DatasetName": str,
+        "Domain": DomainType,
+        "DatasetType": DatasetTypeType,
+        "Schema": "SchemaTypeDef",
+    },
+)
+_OptionalCreateDatasetRequestTypeDef = TypedDict(
+    "_OptionalCreateDatasetRequestTypeDef",
+    {
+        "DataFrequency": str,
+        "EncryptionConfig": "EncryptionConfigTypeDef",
+        "Tags": List["TagTypeDef"],
     },
     total=False,
 )
 
-CreateDatasetResponseTypeDef = TypedDict(
-    "CreateDatasetResponseTypeDef",
+
+class CreateDatasetRequestTypeDef(
+    _RequiredCreateDatasetRequestTypeDef, _OptionalCreateDatasetRequestTypeDef
+):
+    pass
+
+
+CreateDatasetResponseResponseTypeDef = TypedDict(
+    "CreateDatasetResponseResponseTypeDef",
     {
         "DatasetArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreateForecastExportJobRequestTypeDef = TypedDict(
+    "_RequiredCreateForecastExportJobRequestTypeDef",
+    {
+        "ForecastExportJobName": str,
+        "ForecastArn": str,
+        "Destination": "DataDestinationTypeDef",
+    },
+)
+_OptionalCreateForecastExportJobRequestTypeDef = TypedDict(
+    "_OptionalCreateForecastExportJobRequestTypeDef",
+    {
+        "Tags": List["TagTypeDef"],
     },
     total=False,
 )
 
-CreateForecastExportJobResponseTypeDef = TypedDict(
-    "CreateForecastExportJobResponseTypeDef",
+
+class CreateForecastExportJobRequestTypeDef(
+    _RequiredCreateForecastExportJobRequestTypeDef, _OptionalCreateForecastExportJobRequestTypeDef
+):
+    pass
+
+
+CreateForecastExportJobResponseResponseTypeDef = TypedDict(
+    "CreateForecastExportJobResponseResponseTypeDef",
     {
         "ForecastExportJobArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-CreateForecastResponseTypeDef = TypedDict(
-    "CreateForecastResponseTypeDef",
-    {
-        "ForecastArn": str,
-    },
-    total=False,
-)
-
-CreatePredictorBacktestExportJobResponseTypeDef = TypedDict(
-    "CreatePredictorBacktestExportJobResponseTypeDef",
-    {
-        "PredictorBacktestExportJobArn": str,
-    },
-    total=False,
-)
-
-CreatePredictorResponseTypeDef = TypedDict(
-    "CreatePredictorResponseTypeDef",
+_RequiredCreateForecastRequestTypeDef = TypedDict(
+    "_RequiredCreateForecastRequestTypeDef",
     {
+        "ForecastName": str,
         "PredictorArn": str,
     },
+)
+_OptionalCreateForecastRequestTypeDef = TypedDict(
+    "_OptionalCreateForecastRequestTypeDef",
+    {
+        "ForecastTypes": List[str],
+        "Tags": List["TagTypeDef"],
+    },
     total=False,
 )
 
+
+class CreateForecastRequestTypeDef(
+    _RequiredCreateForecastRequestTypeDef, _OptionalCreateForecastRequestTypeDef
+):
+    pass
+
+
+CreateForecastResponseResponseTypeDef = TypedDict(
+    "CreateForecastResponseResponseTypeDef",
+    {
+        "ForecastArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreatePredictorBacktestExportJobRequestTypeDef = TypedDict(
+    "_RequiredCreatePredictorBacktestExportJobRequestTypeDef",
+    {
+        "PredictorBacktestExportJobName": str,
+        "PredictorArn": str,
+        "Destination": "DataDestinationTypeDef",
+    },
+)
+_OptionalCreatePredictorBacktestExportJobRequestTypeDef = TypedDict(
+    "_OptionalCreatePredictorBacktestExportJobRequestTypeDef",
+    {
+        "Tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreatePredictorBacktestExportJobRequestTypeDef(
+    _RequiredCreatePredictorBacktestExportJobRequestTypeDef,
+    _OptionalCreatePredictorBacktestExportJobRequestTypeDef,
+):
+    pass
+
+
+CreatePredictorBacktestExportJobResponseResponseTypeDef = TypedDict(
+    "CreatePredictorBacktestExportJobResponseResponseTypeDef",
+    {
+        "PredictorBacktestExportJobArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredCreatePredictorRequestTypeDef = TypedDict(
+    "_RequiredCreatePredictorRequestTypeDef",
+    {
+        "PredictorName": str,
+        "ForecastHorizon": int,
+        "InputDataConfig": "InputDataConfigTypeDef",
+        "FeaturizationConfig": "FeaturizationConfigTypeDef",
+    },
+)
+_OptionalCreatePredictorRequestTypeDef = TypedDict(
+    "_OptionalCreatePredictorRequestTypeDef",
+    {
+        "AlgorithmArn": str,
+        "ForecastTypes": List[str],
+        "PerformAutoML": bool,
+        "AutoMLOverrideStrategy": Literal["LatencyOptimized"],
+        "PerformHPO": bool,
+        "TrainingParameters": Dict[str, str],
+        "EvaluationParameters": "EvaluationParametersTypeDef",
+        "HPOConfig": "HyperParameterTuningJobConfigTypeDef",
+        "EncryptionConfig": "EncryptionConfigTypeDef",
+        "Tags": List["TagTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreatePredictorRequestTypeDef(
+    _RequiredCreatePredictorRequestTypeDef, _OptionalCreatePredictorRequestTypeDef
+):
+    pass
+
+
+CreatePredictorResponseResponseTypeDef = TypedDict(
+    "CreatePredictorResponseResponseTypeDef",
+    {
+        "PredictorArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DataDestinationTypeDef = TypedDict(
     "DataDestinationTypeDef",
     {
@@ -235,8 +450,71 @@ DatasetSummaryTypeDef = TypedDict(
     total=False,
 )
 
-DescribeDatasetGroupResponseTypeDef = TypedDict(
-    "DescribeDatasetGroupResponseTypeDef",
+DeleteDatasetGroupRequestTypeDef = TypedDict(
+    "DeleteDatasetGroupRequestTypeDef",
+    {
+        "DatasetGroupArn": str,
+    },
+)
+
+DeleteDatasetImportJobRequestTypeDef = TypedDict(
+    "DeleteDatasetImportJobRequestTypeDef",
+    {
+        "DatasetImportJobArn": str,
+    },
+)
+
+DeleteDatasetRequestTypeDef = TypedDict(
+    "DeleteDatasetRequestTypeDef",
+    {
+        "DatasetArn": str,
+    },
+)
+
+DeleteForecastExportJobRequestTypeDef = TypedDict(
+    "DeleteForecastExportJobRequestTypeDef",
+    {
+        "ForecastExportJobArn": str,
+    },
+)
+
+DeleteForecastRequestTypeDef = TypedDict(
+    "DeleteForecastRequestTypeDef",
+    {
+        "ForecastArn": str,
+    },
+)
+
+DeletePredictorBacktestExportJobRequestTypeDef = TypedDict(
+    "DeletePredictorBacktestExportJobRequestTypeDef",
+    {
+        "PredictorBacktestExportJobArn": str,
+    },
+)
+
+DeletePredictorRequestTypeDef = TypedDict(
+    "DeletePredictorRequestTypeDef",
+    {
+        "PredictorArn": str,
+    },
+)
+
+DeleteResourceTreeRequestTypeDef = TypedDict(
+    "DeleteResourceTreeRequestTypeDef",
+    {
+        "ResourceArn": str,
+    },
+)
+
+DescribeDatasetGroupRequestTypeDef = TypedDict(
+    "DescribeDatasetGroupRequestTypeDef",
+    {
+        "DatasetGroupArn": str,
+    },
+)
+
+DescribeDatasetGroupResponseResponseTypeDef = TypedDict(
+    "DescribeDatasetGroupResponseResponseTypeDef",
     {
         "DatasetGroupName": str,
         "DatasetGroupArn": str,
@@ -245,12 +523,19 @@ DescribeDatasetGroupResponseTypeDef = TypedDict(
         "Status": str,
         "CreationTime": datetime,
         "LastModificationTime": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-DescribeDatasetImportJobResponseTypeDef = TypedDict(
-    "DescribeDatasetImportJobResponseTypeDef",
+DescribeDatasetImportJobRequestTypeDef = TypedDict(
+    "DescribeDatasetImportJobRequestTypeDef",
+    {
+        "DatasetImportJobArn": str,
+    },
+)
+
+DescribeDatasetImportJobResponseResponseTypeDef = TypedDict(
+    "DescribeDatasetImportJobResponseResponseTypeDef",
     {
         "DatasetImportJobName": str,
         "DatasetImportJobArn": str,
@@ -267,12 +552,19 @@ DescribeDatasetImportJobResponseTypeDef = TypedDict(
         "Message": str,
         "CreationTime": datetime,
         "LastModificationTime": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-DescribeDatasetResponseTypeDef = TypedDict(
-    "DescribeDatasetResponseTypeDef",
+DescribeDatasetRequestTypeDef = TypedDict(
+    "DescribeDatasetRequestTypeDef",
+    {
+        "DatasetArn": str,
+    },
+)
+
+DescribeDatasetResponseResponseTypeDef = TypedDict(
+    "DescribeDatasetResponseResponseTypeDef",
     {
         "DatasetArn": str,
         "DatasetName": str,
@@ -284,12 +576,19 @@ DescribeDatasetResponseTypeDef = TypedDict(
         "Status": str,
         "CreationTime": datetime,
         "LastModificationTime": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-DescribeForecastExportJobResponseTypeDef = TypedDict(
-    "DescribeForecastExportJobResponseTypeDef",
+DescribeForecastExportJobRequestTypeDef = TypedDict(
+    "DescribeForecastExportJobRequestTypeDef",
+    {
+        "ForecastExportJobArn": str,
+    },
+)
+
+DescribeForecastExportJobResponseResponseTypeDef = TypedDict(
+    "DescribeForecastExportJobResponseResponseTypeDef",
     {
         "ForecastExportJobArn": str,
         "ForecastExportJobName": str,
@@ -299,12 +598,19 @@ DescribeForecastExportJobResponseTypeDef = TypedDict(
         "Status": str,
         "CreationTime": datetime,
         "LastModificationTime": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-DescribeForecastResponseTypeDef = TypedDict(
-    "DescribeForecastResponseTypeDef",
+DescribeForecastRequestTypeDef = TypedDict(
+    "DescribeForecastRequestTypeDef",
+    {
+        "ForecastArn": str,
+    },
+)
+
+DescribeForecastResponseResponseTypeDef = TypedDict(
+    "DescribeForecastResponseResponseTypeDef",
     {
         "ForecastArn": str,
         "ForecastName": str,
@@ -316,12 +622,19 @@ DescribeForecastResponseTypeDef = TypedDict(
         "Message": str,
         "CreationTime": datetime,
         "LastModificationTime": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-DescribePredictorBacktestExportJobResponseTypeDef = TypedDict(
-    "DescribePredictorBacktestExportJobResponseTypeDef",
+DescribePredictorBacktestExportJobRequestTypeDef = TypedDict(
+    "DescribePredictorBacktestExportJobRequestTypeDef",
+    {
+        "PredictorBacktestExportJobArn": str,
+    },
+)
+
+DescribePredictorBacktestExportJobResponseResponseTypeDef = TypedDict(
+    "DescribePredictorBacktestExportJobResponseResponseTypeDef",
     {
         "PredictorBacktestExportJobArn": str,
         "PredictorBacktestExportJobName": str,
@@ -331,12 +644,19 @@ DescribePredictorBacktestExportJobResponseTypeDef = TypedDict(
         "Status": str,
         "CreationTime": datetime,
         "LastModificationTime": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-DescribePredictorResponseTypeDef = TypedDict(
-    "DescribePredictorResponseTypeDef",
+DescribePredictorRequestTypeDef = TypedDict(
+    "DescribePredictorRequestTypeDef",
+    {
+        "PredictorArn": str,
+    },
+)
+
+DescribePredictorResponseResponseTypeDef = TypedDict(
+    "DescribePredictorResponseResponseTypeDef",
     {
         "PredictorArn": str,
         "PredictorName": str,
@@ -360,8 +680,8 @@ DescribePredictorResponseTypeDef = TypedDict(
         "Message": str,
         "CreationTime": datetime,
         "LastModificationTime": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 EncryptionConfigTypeDef = TypedDict(
@@ -500,13 +820,20 @@ ForecastSummaryTypeDef = TypedDict(
     total=False,
 )
 
-GetAccuracyMetricsResponseTypeDef = TypedDict(
-    "GetAccuracyMetricsResponseTypeDef",
+GetAccuracyMetricsRequestTypeDef = TypedDict(
+    "GetAccuracyMetricsRequestTypeDef",
+    {
+        "PredictorArn": str,
+    },
+)
+
+GetAccuracyMetricsResponseResponseTypeDef = TypedDict(
+    "GetAccuracyMetricsResponseResponseTypeDef",
     {
         "PredictorEvaluationResults": List["EvaluationResultTypeDef"],
         "AutoMLOverrideStrategy": Literal["LatencyOptimized"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 HyperParameterTuningJobConfigTypeDef = TypedDict(
@@ -559,75 +886,150 @@ class IntegerParameterRangeTypeDef(
     pass
 
 
-ListDatasetGroupsResponseTypeDef = TypedDict(
-    "ListDatasetGroupsResponseTypeDef",
+ListDatasetGroupsRequestTypeDef = TypedDict(
+    "ListDatasetGroupsRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+ListDatasetGroupsResponseResponseTypeDef = TypedDict(
+    "ListDatasetGroupsResponseResponseTypeDef",
     {
         "DatasetGroups": List["DatasetGroupSummaryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListDatasetImportJobsRequestTypeDef = TypedDict(
+    "ListDatasetImportJobsRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+        "Filters": List["FilterTypeDef"],
     },
     total=False,
 )
 
-ListDatasetImportJobsResponseTypeDef = TypedDict(
-    "ListDatasetImportJobsResponseTypeDef",
+ListDatasetImportJobsResponseResponseTypeDef = TypedDict(
+    "ListDatasetImportJobsResponseResponseTypeDef",
     {
         "DatasetImportJobs": List["DatasetImportJobSummaryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListDatasetsRequestTypeDef = TypedDict(
+    "ListDatasetsRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
     },
     total=False,
 )
 
-ListDatasetsResponseTypeDef = TypedDict(
-    "ListDatasetsResponseTypeDef",
+ListDatasetsResponseResponseTypeDef = TypedDict(
+    "ListDatasetsResponseResponseTypeDef",
     {
         "Datasets": List["DatasetSummaryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListForecastExportJobsRequestTypeDef = TypedDict(
+    "ListForecastExportJobsRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+        "Filters": List["FilterTypeDef"],
     },
     total=False,
 )
 
-ListForecastExportJobsResponseTypeDef = TypedDict(
-    "ListForecastExportJobsResponseTypeDef",
+ListForecastExportJobsResponseResponseTypeDef = TypedDict(
+    "ListForecastExportJobsResponseResponseTypeDef",
     {
         "ForecastExportJobs": List["ForecastExportJobSummaryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListForecastsRequestTypeDef = TypedDict(
+    "ListForecastsRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+        "Filters": List["FilterTypeDef"],
     },
     total=False,
 )
 
-ListForecastsResponseTypeDef = TypedDict(
-    "ListForecastsResponseTypeDef",
+ListForecastsResponseResponseTypeDef = TypedDict(
+    "ListForecastsResponseResponseTypeDef",
     {
         "Forecasts": List["ForecastSummaryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListPredictorBacktestExportJobsRequestTypeDef = TypedDict(
+    "ListPredictorBacktestExportJobsRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+        "Filters": List["FilterTypeDef"],
     },
     total=False,
 )
 
-ListPredictorBacktestExportJobsResponseTypeDef = TypedDict(
-    "ListPredictorBacktestExportJobsResponseTypeDef",
+ListPredictorBacktestExportJobsResponseResponseTypeDef = TypedDict(
+    "ListPredictorBacktestExportJobsResponseResponseTypeDef",
     {
         "PredictorBacktestExportJobs": List["PredictorBacktestExportJobSummaryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListPredictorsRequestTypeDef = TypedDict(
+    "ListPredictorsRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+        "Filters": List["FilterTypeDef"],
     },
     total=False,
 )
 
-ListPredictorsResponseTypeDef = TypedDict(
-    "ListPredictorsResponseTypeDef",
+ListPredictorsResponseResponseTypeDef = TypedDict(
+    "ListPredictorsResponseResponseTypeDef",
     {
         "Predictors": List["PredictorSummaryTypeDef"],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
+ListTagsForResourceRequestTypeDef = TypedDict(
+    "ListTagsForResourceRequestTypeDef",
+    {
+        "ResourceArn": str,
+    },
+)
+
+ListTagsForResourceResponseResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseResponseTypeDef",
     {
         "Tags": List["TagTypeDef"],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 MetricsTypeDef = TypedDict(
@@ -705,6 +1107,17 @@ PredictorSummaryTypeDef = TypedDict(
     total=False,
 )
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 _RequiredS3ConfigTypeDef = TypedDict(
     "_RequiredS3ConfigTypeDef",
     {
@@ -761,6 +1174,13 @@ StatisticsTypeDef = TypedDict(
     total=False,
 )
 
+StopResourceRequestTypeDef = TypedDict(
+    "StopResourceRequestTypeDef",
+    {
+        "ResourceArn": str,
+    },
+)
+
 SupplementaryFeatureTypeDef = TypedDict(
     "SupplementaryFeatureTypeDef",
     {
@@ -769,6 +1189,14 @@ SupplementaryFeatureTypeDef = TypedDict(
     },
 )
 
+TagResourceRequestTypeDef = TypedDict(
+    "TagResourceRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "Tags": List["TagTypeDef"],
+    },
+)
+
 TagTypeDef = TypedDict(
     "TagTypeDef",
     {
@@ -788,6 +1216,22 @@ TestWindowSummaryTypeDef = TypedDict(
     total=False,
 )
 
+UntagResourceRequestTypeDef = TypedDict(
+    "UntagResourceRequestTypeDef",
+    {
+        "ResourceArn": str,
+        "TagKeys": List[str],
+    },
+)
+
+UpdateDatasetGroupRequestTypeDef = TypedDict(
+    "UpdateDatasetGroupRequestTypeDef",
+    {
+        "DatasetGroupArn": str,
+        "DatasetArns": List[str],
+    },
+)
+
 WeightedQuantileLossTypeDef = TypedDict(
     "WeightedQuantileLossTypeDef",
     {
